/*
 *   EXAMPLE SQL FILE FOR TESTING sql2diagram-sxd
 *
 *   This is actually a real database schema for an
 *   opera production database but the names are in
 *   Finnish so it's probably as good as Lipsum for
 *   most of you. :)
 */

/*
Table struture for aliteokset
*/

CREATE TABLE `aliteokset` (
  `teosid` int(10) unsigned NOT NULL default '0',
  `aliteosid` int(10) unsigned NOT NULL default '0',
  `huom` text,
  PRIMARY KEY  (`teosid`,`aliteosid`),
  KEY `teosid` (`teosid`),
  KEY `aliteosid` (`aliteosid`),
  FOREIGN KEY (`teosid`) REFERENCES `teos` (`teosid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`aliteosid`) REFERENCES `teos` (`teosid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for arktallenne
*/

CREATE TABLE `arktallenne` (
  `tallenneid` int(10) unsigned NOT NULL auto_increment primary key,
  `arktunnus` varchar(32) default NULL,
  `sijainti` int(10) default NULL,
  `otsikko` varchar(100) default NULL,
  `alkupvm` date default NULL,
  `loppupvm` date default NULL,
  `sistyyppi` varchar(16) NOT NULL default '',
  `fyysinenmuoto` varchar(16) NOT NULL default '',
  `formaatti` varchar(64) default NULL,
  `tarkoitus` varchar(32) default NULL,
  `julkaisija` varchar(128) default NULL,
  `kpl` int(5) default '1',
  `kuvaus` text,
  `huom` text,
  `avoin` char(1) NOT NULL default '0',
  KEY `tallenneid` (`tallenneid`),
  KEY `sijainti` (`sijainti`),
  KEY `sistyyppi` (`sistyyppi`),
  KEY `fyysinenmuoto` (`fyysinenmuoto`),
  KEY `tarkoitus` (`tarkoitus`),
  KEY `arktunnus` (`arktunnus`),
  FOREIGN KEY (`arktunnus`) REFERENCES `arktallennetunnus` (`arktunnus`) ON UPDATE CASCADE,
  FOREIGN KEY (`sijainti`) REFERENCES `arktallenne` (`tallenneid`) ON UPDATE CASCADE,
  FOREIGN KEY (`sistyyppi`) REFERENCES `arktallennesistyyppi` (`sistyyppi`) ON UPDATE CASCADE,
  FOREIGN KEY (`fyysinenmuoto`) REFERENCES `arktallennefmuoto` (`fyysinenmuoto`) ON UPDATE CASCADE,
  FOREIGN KEY (`tarkoitus`) REFERENCES `arktallennetarkoitus` (`tarkoitus`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for arktallennefmuoto
*/

CREATE TABLE `arktallennefmuoto` (
  `fyysinenmuoto` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `kuvaus` varchar(128) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`fyysinenmuoto`)
) TYPE=InnoDB;

/*
Table struture for arktallennehenkilot
*/

CREATE TABLE `arktallennehenkilot` (
  `tallenneid` int(10) unsigned NOT NULL default '0',
  `henkiloid` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`tallenneid`,`henkiloid`),
  KEY `tallenneid` (`tallenneid`),
  KEY `henkiloid` (`henkiloid`),
  FOREIGN KEY (`tallenneid`) REFERENCES `arktallenne` (`tallenneid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`henkiloid`) REFERENCES `henkilo` (`henkiloid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for arktallennesistyyppi
*/

CREATE TABLE `arktallennesistyyppi` (
  `sistyyppi` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `kuvaus` varchar(128) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`sistyyppi`)
) TYPE=InnoDB;

/*
Table struture for arktallennetarkoitus
*/

CREATE TABLE `arktallennetarkoitus` (
  `tarkoitus` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `kuvaus` varchar(128) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`tarkoitus`)
) TYPE=InnoDB;

/*
Table struture for arktallenneteokset
*/

CREATE TABLE `arktallenneteokset` (
  `tallenneid` int(10) unsigned NOT NULL default '0',
  `teosid` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`tallenneid`,`teosid`),
  KEY `tallenneid` (`tallenneid`),
  KEY `teosid` (`teosid`),
  FOREIGN KEY (`tallenneid`) REFERENCES `arktallenne` (`tallenneid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`teosid`) REFERENCES `teos` (`teosid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for arktallennetunnus
*/

CREATE TABLE `arktallennetunnus` (
  `arktunnus` varchar(16) NOT NULL default '',
  `otsikko` varchar(128) NOT NULL default '',
  PRIMARY KEY  (`arktunnus`)
) TYPE=InnoDB;

/*
Table struture for arktallennetuotannot
*/

CREATE TABLE `arktallennetuotannot` (
  `tallenneid` int(10) unsigned NOT NULL default '0',
  `tuotantoid` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`tallenneid`,`tuotantoid`),
  KEY `tallenneid` (`tallenneid`),
  KEY `tuotantoid` (`tuotantoid`),
  FOREIGN KEY (`tallenneid`) REFERENCES `arktallenne` (`tallenneid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`tuotantoid`) REFERENCES `tuotanto` (`tuotantoid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for henkilo
*/

CREATE TABLE `henkilo` (
  `henkiloid` int(10) unsigned NOT NULL auto_increment,
  `syntynyt` date default NULL,
  `kuollut` date default NULL,
  `aidinkieli` char(3) NOT NULL default 'und',
  `huom` text,
  `sukunimi` varchar(64) default NULL,
  `etunimi` varchar(64) default NULL,
  `toinennimi` varchar(64) default NULL,
  `sukupuoli` enum('n/a','mies','nainen') default NULL,
  PRIMARY KEY  (`henkiloid`),
  KEY `henkiloid` (`henkiloid`),
  KEY `aidinkieli` (`aidinkieli`),
  FOREIGN KEY (`aidinkieli`) REFERENCES `kieli` (`kielikoodi`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for kieli
*/

CREATE TABLE `kieli` (
  `kielikoodi` char(3) NOT NULL default '',
  `nimi` varchar(64) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`kielikoodi`),
  KEY `prioriteetti` (`prioriteetti`,`nimi`),
  KEY `kielikoodi` (`kielikoodi`)
) TYPE=InnoDB;

/*
Table struture for ongelma
*/

CREATE TABLE `ongelma` (
  `ongelmaid` int(10) unsigned NOT NULL auto_increment,
  `otsikko` tinytext,
  `selitys` text,
  `avattu` date default NULL,
  `suljettu` date default NULL,
  PRIMARY KEY  (`ongelmaid`),
  KEY `avattu` (`avattu`,`suljettu`)
) TYPE=MyISAM;

/*
Table struture for teos
*/

CREATE TABLE `teos` (
  `teosid` int(10) unsigned NOT NULL auto_increment,
  `tyyppi` varchar(16) NOT NULL default 'muu',
  `huom` text,
  `kantaesitys` date default NULL,
  PRIMARY KEY  (`teosid`),
  KEY `teosid` (`teosid`),
  KEY `tyyppi` (`tyyppi`),
  FOREIGN KEY (`tyyppi`) REFERENCES `teostyyppi` (`tyyppi`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for teosnimet
*/

CREATE TABLE `teosnimet` (
  `teosid` int(10) unsigned NOT NULL default '0',
  `nimi` varchar(128) NOT NULL default '',
  `kielikoodi` char(3) NOT NULL default 'und',
  `teosnimiid` int(10) unsigned NOT NULL auto_increment,
  PRIMARY KEY  (`teosnimiid`),
  UNIQUE KEY `teosid_2` (`teosid`,`nimi`,`kielikoodi`),
  KEY `teosid` (`teosid`),
  KEY `kielikoodi` (`kielikoodi`),
  FOREIGN KEY (`kielikoodi`) REFERENCES `kieli` (`kielikoodi`) ON UPDATE CASCADE,
  FOREIGN KEY (`teosid`) REFERENCES `teos` (`teosid`) ON DELETE CASCADE ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for teostehtava
*/

CREATE TABLE `teostehtava` (
  `tehtava` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`tehtava`)
) TYPE=InnoDB;

/*
Table struture for teostekijat
*/

CREATE TABLE `teostekijat` (
  `teosid` int(10) unsigned NOT NULL default '0',
  `henkiloid` int(10) unsigned NOT NULL default '0',
  `tehtava` varchar(16) NOT NULL default '',
  `huom` text,
  PRIMARY KEY  (`teosid`,`henkiloid`,`tehtava`),
  KEY `teosid` (`teosid`),
  KEY `henkiloid` (`henkiloid`),
  KEY `tehtava` (`tehtava`),
  FOREIGN KEY (`tehtava`) REFERENCES `teostehtava` (`tehtava`) ON UPDATE CASCADE,
  FOREIGN KEY (`teosid`) REFERENCES `teos` (`teosid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`henkiloid`) REFERENCES `henkilo` (`henkiloid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for teostyyppi
*/

CREATE TABLE `teostyyppi` (
  `tyyppi` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`tyyppi`)
) TYPE=InnoDB;

/*
Table struture for tuotanto
*/

CREATE TABLE `tuotanto` (
  `tuotantoid` int(10) unsigned NOT NULL auto_increment,
  `ensiiltapvm` date default NULL,
  `poistopvm` date default NULL,
  `tunnus` varchar(16) default NULL,
  `nimi` varchar(128) default NULL,
  `huom` text,
  `tyyppi` varchar(16) NOT NULL default '',
  PRIMARY KEY  (`tuotantoid`),
  KEY `tuotantoid` (`tuotantoid`),
  KEY `tyyppi` (`tyyppi`),
  FOREIGN KEY (`tyyppi`) REFERENCES `tuotantotyyppi` (`tyyppi`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for tuotantotehtava
*/

CREATE TABLE `tuotantotehtava` (
  `tehtava` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`tehtava`)
) TYPE=InnoDB;

/*
Table struture for tuotantotekijat
*/

CREATE TABLE `tuotantotekijat` (
  `tuotantoid` int(10) unsigned NOT NULL default '0',
  `henkiloid` int(10) unsigned NOT NULL default '0',
  `tehtava` varchar(16) NOT NULL default 'muu',
  `huom` text,
  PRIMARY KEY  (`tuotantoid`,`henkiloid`,`tehtava`),
  KEY `tuotantoid` (`tuotantoid`),
  KEY `henkiloid` (`henkiloid`),
  KEY `tehtava` (`tehtava`),
  FOREIGN KEY (`tehtava`) REFERENCES `tuotantotehtava` (`tehtava`) ON UPDATE CASCADE,
  FOREIGN KEY (`henkiloid`) REFERENCES `henkilo` (`henkiloid`) ON UPDATE CASCADE,
  FOREIGN KEY (`tuotantoid`) REFERENCES `tuotanto` (`tuotantoid`) ON DELETE CASCADE ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for tuotantoteokset
*/

CREATE TABLE `tuotantoteokset` (
  `tuotantoid` int(10) unsigned NOT NULL default '0',
  `teosid` int(10) unsigned NOT NULL default '0',
  `huom` tinytext,
  PRIMARY KEY  (`tuotantoid`,`teosid`),
  KEY `tuotantoid` (`tuotantoid`),
  KEY `teosid` (`teosid`),
  FOREIGN KEY (`tuotantoid`) REFERENCES `tuotanto` (`tuotantoid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`teosid`) REFERENCES `teos` (`teosid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for tuotantotyyppi
*/

CREATE TABLE `tuotantotyyppi` (
  `tyyppi` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`tyyppi`)
) TYPE=InnoDB;

/*
Table struture for vlehti
*/

CREATE TABLE `vlehti` (
  `vlehtiid` int(10) unsigned NOT NULL auto_increment,
  `pvm` date default NULL,
  `tiedostonimi` varchar(250) default NULL,
  `lehtiryhmaid` int(10) unsigned default NULL,
  `teksti` text,
  `originaaliteksti` text,
  `muutettu` timestamp(14) NOT NULL,
  `sivunumero` int(3) default NULL,
  `luokat` set('ohjelma','tekijat','juonikuvaus','korjaus','henkiloesittely','teosesittely','muuesittely','pohdintaa') NOT NULL default '',
  PRIMARY KEY  (`vlehtiid`),
  KEY `pvm` (`pvm`),
  KEY `lehtiryhmaid` (`lehtiryhmaid`),
  KEY `muutettu` (`muutettu`),
  KEY `tiedostonimi` (`tiedostonimi`)
) TYPE=InnoDB;

/*
Table struture for vlehtihaku
*/

CREATE TABLE `vlehtihaku` (
  `hakuid` int(10) unsigned NOT NULL auto_increment,
  `hakuteksti` varchar(200) NOT NULL default '',
  `maxvirhe` int(5) NOT NULL default '0',
  `minpvm` date default NULL,
  `maxpvm` date default NULL,
  `hakuaika` timestamp(14) NOT NULL,
  `valmis` char(1) NOT NULL default '0',
  PRIMARY KEY  (`hakuid`),
  UNIQUE KEY `hakuteksti` (`hakuteksti`,`maxvirhe`),
  KEY `hakuid` (`hakuid`),
  KEY `hakuaika` (`hakuaika`)
) TYPE=InnoDB;

/*
Table struture for vlehtihakutulokset
*/

CREATE TABLE `vlehtihakutulokset` (
  `hakuid` int(10) unsigned NOT NULL default '0',
  `vlehtiid` int(10) unsigned NOT NULL default '0',
  `alkukohta` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`hakuid`,`vlehtiid`),
  KEY `vlehtiid` (`vlehtiid`),
  FOREIGN KEY (`hakuid`) REFERENCES `vlehtihaku` (`hakuid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`vlehtiid`) REFERENCES `vlehti` (`vlehtiid`) ON DELETE CASCADE ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for vlehtihenkilot
*/

CREATE TABLE `vlehtihenkilot` (
  `vlehtiid` int(10) unsigned NOT NULL default '0',
  `henkiloid` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`vlehtiid`,`henkiloid`),
  KEY `henkiloid` (`henkiloid`),
  FOREIGN KEY (`vlehtiid`) REFERENCES `vlehti` (`vlehtiid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`henkiloid`) REFERENCES `henkilo` (`henkiloid`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for vlehtiluokat
*/

CREATE TABLE `vlehtiluokat` (
  `vlehtiid` int(10) unsigned NOT NULL default '0',
  `luokka` varchar(16) NOT NULL default '',
  PRIMARY KEY  (`vlehtiid`,`luokka`),
  KEY `luokka` (`luokka`),
  KEY `vlehtiid` (`vlehtiid`),
  FOREIGN KEY (`vlehtiid`) REFERENCES `vlehti` (`vlehtiid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`luokka`) REFERENCES `vlehtiluokka` (`luokka`) ON UPDATE CASCADE
) TYPE=InnoDB;

/*
Table struture for vlehtiluokka
*/

CREATE TABLE `vlehtiluokka` (
  `luokka` varchar(16) NOT NULL default '',
  `otsikko` varchar(64) NOT NULL default '',
  `prioriteetti` int(5) NOT NULL default '0',
  PRIMARY KEY  (`luokka`)
) TYPE=InnoDB;

/*
Table struture for vlehtiteokset
*/

CREATE TABLE `vlehtiteokset` (
  `vlehtiid` int(10) unsigned NOT NULL default '0',
  `teosid` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`vlehtiid`,`teosid`),
  KEY `teosid` (`teosid`),
  FOREIGN KEY (`vlehtiid`) REFERENCES `vlehti` (`vlehtiid`) ON DELETE CASCADE ON UPDATE CASCADE,
  FOREIGN KEY (`teosid`) REFERENCES `teos` (`teosid`) ON UPDATE CASCADE
) TYPE=InnoDB;

